@@ -10,19 +10,33 @@ class Contacts(ApiBase):
     Class for Contacts API
     """
 
-    GET_CONTACTS = '/api.xro/2.0/contacts'
-    POST_CONTACTS = '/api.xro/2.0/contacts'
-    SEARCH_CONTACT = '/api.xro/2.0/Contacts?where=Name="{0}"'
+    GET_CONTACTS = '/api.xro/2.0/Contacts'
+    POST_CONTACTS = '/api.xro/2.0/Contacts'
 
-    def get_all(self):
+    def get_all(self, modified_after: str = None):
         """
         Get all contacts
 
+        :param modified_after: Optional modified_after parameter as a string in 2009-11-12T00:00:00 format
+
         Returns:
             List of all contacts
         """
 
-        return self._get_request(Contacts.GET_CONTACTS)
+        return self._get_request(Contacts.GET_CONTACTS, additional_headers={'If-Modified-Since': modified_after})
+
+    def list_all_generator(self, modified_after: str = None):
+        """
+        Get all contacts
+
+        :param modified_after: Optional modified_after parameter as a string in 2009-11-12T00:00:00 format
+
+        Returns:
+            List of all contacts with pagination
+        """
+
+        return self._get_all_generator(
+            Contacts.GET_CONTACTS, 'Contacts', additional_headers={'If-Modified-Since': modified_after})
 
     def post(self, data):
         """
@@ -44,6 +58,6 @@ class Contacts(ApiBase):
         :return: Contact
         """
 
-        response = self._get_request(Contacts.SEARCH_CONTACT.format(contact_name))
+        response = self._search_request(Contacts.GET_CONTACTS, 'Name', contact_name)
 
         return response['Contacts'][0] if response['Contacts'] else None
